﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class ComponentCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();
        
        /// <summary>
        /// Comprovem existència d'un Component.
        /// </summary>
        /// <param name="ID_Component"></param>
        /// <returns></returns>
        public Boolean existeixComponent(int ID_Component)
        {
            try
            {
                var consulta = (from d in dc.Components
                                where d.ID_Component.Equals(ID_Component)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix el Component", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Llistar tots els Components
        /// </summary>
        /// <returns>llista</returns>
        public List<ComponentEntity> GetAllComponents()
        {

            List<ComponentEntity> llista = new List<ComponentEntity>();
            try
            {
                var consulta = (from d in dc.Components
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    ComponentEntity obj = new ComponentEntity();
                    obj.ID_Component = d.ID_Component;
                    obj.Nom_Component = d.Nom_Component;
                    obj.Descripcio = d.Descripcio;
                    obj.Estat = d.Estat;
                    obj.Data_Alta_Compo = Convert.ToDateTime(d.Data_Alta_Compo);
                    obj.Data_Baixa_Compo = Convert.ToDateTime(d.Data_Baixa_Compo);
                    obj.ID_Tipus_Compo = d.ID_Tipus_Compo;
                    obj.ID_Estructura = Convert.ToInt32(d.ID_Estructura);
                    obj.Cost = Convert.ToDecimal(d.Cost);
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar tots els Components", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }

        /// <summary>
        /// Llistar Estructura per:
        /// tipusConsulta = 1 per ID_Component
        ///                 2 per Nom_Component
        ///                 3 per ID_Estructura
        /// </summary>
        /// <returns>llista</returns>
        public List<ComponentEntity> llistarComponent(int tipusConsulta, string valorBuscat)
        {
            try
            {

                List<ComponentEntity> llista = new List<ComponentEntity>();

                /// Per ID_Component

                if (tipusConsulta == 1)
                {
                    int valorn = 0;

                    var consulta = (from d in dc.Components
                                    where d.ID_Component.Equals(valorn)
                                    select d);

                    foreach (var d in consulta)
                    {
                        ComponentEntity obj = new ComponentEntity();
                        obj.ID_Component = d.ID_Component;
                        obj.Nom_Component = d.Nom_Component;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Compo = Convert.ToDateTime(d.Data_Alta_Compo);
                        obj.Data_Baixa_Compo = Convert.ToDateTime(d.Data_Baixa_Compo);
                        obj.ID_Tipus_Compo = d.ID_Tipus_Compo;
                        obj.ID_Estructura = Convert.ToInt32(d.ID_Estructura);
                        obj.Cost = Convert.ToDecimal(d.Cost);                        
                        llista.Add(obj);
                    }
                }

                /// Per nom Component

                if (tipusConsulta == 2)
                {
                    var consulta = (from d in dc.Components
                                    where (d.Nom_Component.Contains(valorBuscat))
                                    orderby d.Nom_Component
                                    select d);

                    foreach (var d in consulta)
                    {
                        ComponentEntity obj = new ComponentEntity();
                        obj.ID_Component = d.ID_Component;
                        obj.Nom_Component = d.Nom_Component;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Compo = Convert.ToDateTime(d.Data_Alta_Compo);
                        obj.Data_Baixa_Compo = Convert.ToDateTime(d.Data_Baixa_Compo);
                        obj.ID_Tipus_Compo = d.ID_Tipus_Compo;
                        obj.ID_Estructura = Convert.ToInt32(d.ID_Estructura);
                        obj.Cost = Convert.ToDecimal(d.Cost);                        
                        llista.Add(obj);
                    }
                }

                /// Per ID_Estructura

                if (tipusConsulta == 3)
                {


                    var consulta = (from d in dc.Components
                                    where (d.ID_Estructura.Equals(valorBuscat))
                                    orderby d.ID_Estructura
                                    select d);

                    foreach (var d in consulta)
                    {
                        ComponentEntity obj = new ComponentEntity();
                        obj.ID_Component = d.ID_Component;
                        obj.Nom_Component = d.Nom_Component;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Compo = Convert.ToDateTime(d.Data_Alta_Compo);
                        obj.Data_Baixa_Compo = Convert.ToDateTime(d.Data_Baixa_Compo);
                        obj.ID_Tipus_Compo = d.ID_Tipus_Compo;
                        obj.ID_Estructura = Convert.ToInt32(d.ID_Estructura);
                        obj.Cost = Convert.ToDecimal(d.Cost);                        
                        llista.Add(obj);
                    }
                }

                return llista;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error en llistar filtrat", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Inserta Component
        /// </summary>
        /// <param name="component"></param>
        public void insertComponent(ComponentEntity component)
        {
            try
            {
                Components obj = new Components();
                //obj.ID_Component = component.ID_Component; automatic
                obj.Nom_Component = component.Nom_Component;
                obj.Descripcio = component.Descripcio;
                obj.Estat = component.Estat;
                obj.Data_Alta_Compo = component.Data_Alta_Compo;
                if (isDateNull(component.Data_Baixa_Compo) == false)
                {
                    obj.Data_Baixa_Compo = component.Data_Baixa_Compo;
                }
  
                obj.ID_Tipus_Compo = component.ID_Tipus_Compo;
                obj.ID_Estructura = component.ID_Estructura;
                obj.Cost = component.Cost;

                dc.Components.InsertOnSubmit(obj);
                dc.SubmitChanges();

            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar el Component", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Esborra Component
        /// </summary>
        /// <param name="ID_Component"></param>
        public void deleteComponentById(int ID_Component)
        {
            try
            {
                var consulta = (from d in dc.Components
                                where d.ID_Component == ID_Component
                                select d).Single();
                dc.Components.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar el Component", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Actualitza Component
        /// </summary>
        /// <param name="component"></param>
        public void updateComponent(ComponentEntity component)
        {
            var obj = (from d in dc.Components
                       where d.ID_Component == component.ID_Component
                       select d).Single();

            try
            {
                //obj.ID_Component = component.ID_Component; automatic
                obj.Nom_Component = component.Nom_Component;
                obj.Descripcio = component.Descripcio;
                obj.Estat = component.Estat;
                obj.Data_Alta_Compo = component.Data_Alta_Compo;
                obj.Data_Baixa_Compo = component.Data_Baixa_Compo;
                obj.ID_Tipus_Compo = component.ID_Tipus_Compo;
                obj.ID_Estructura = component.ID_Estructura;
                obj.Cost = component.Cost;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al modificar el Component", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        ///
        ///Comprovem si la data es null
        ///
        private Boolean isDateNull(DateTime data)
        {
            if (data.ToString("dd/MM/yyyy") == "01/01/0001")
            {
                return true;
            }
            else
            {
                return false;
            }
        }

    }
}
