﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class DivisioCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

        /// <summary>
        /// Comprovem existència d'una Divisio
        /// </summary>
        /// <param name="ID_Divisio"></param>
        /// <returns></returns>
        public Boolean existeixDivisio(int ID_Divisio)
        {
            try
            {
                var consulta = (from d in dc.Divisions
                                where d.ID_Divisio.Equals(ID_Divisio)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix la Divisio", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Busquem una Divisio
        /// </summary>
        /// <param name="ID_Divisio"></param>
        /// <returns></returns>
        public DivisioEntity buscarDivisio(int ID_Divisio)
        {
            try
            {
                var consulta = (from d in dc.Divisions
                                where d.ID_Divisio.Equals(ID_Divisio)
                                select d).Single();

                DivisioEntity obj = new DivisioEntity();
                obj.ID_Divisio = consulta.ID_Divisio;
                obj.Nom_Divisio = consulta.Nom_Divisio;
                obj.Descripcio = consulta.Descripcio;
                return obj;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es troba la Divisio buscada", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Afegir una Divisio
        /// </summary>
        /// <param name="divisio"></param>
        public void insertDivisio(DivisioEntity divisio)
        {
            try
            {
                Divisions obj = new Divisions();
               // obj.ID_Divisio = divisio.ID_Divisio; automatic
                obj.Nom_Divisio = divisio.Nom_Divisio;
                obj.Descripcio = divisio.Descripcio;

                dc.Divisions.InsertOnSubmit(obj);
                dc.SubmitChanges();
                
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar la Divisio", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Actualitza una Divisio
        /// </summary>
        /// <param name="divisio"></param>
        public void updateDivisio(DivisioEntity divisio)
        {
            var obj = (from d in dc.Divisions
                       where d.ID_Divisio == divisio.ID_Divisio
                       select d).Single();

            try
            {
                // obj.ID_Divisio = divisio.ID_Divisio; automatic
                obj.Nom_Divisio = divisio.Nom_Divisio;
                obj.Descripcio = divisio.Descripcio;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al actualitzar la Divisio", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Eliminar Divisio
        /// </summary>
        /// <param name="ID_Divisio"></param>
        public void deletDivisioByID(int ID_Divisio)
        {
            try
            {
                var consulta = (from d in dc.Divisions
                                where d.ID_Divisio == ID_Divisio
                                select d).Single();
                dc.Divisions.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar la Divisio", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Llistar totes les Division
        /// </summary>
        /// <returns>llista</returns>
        public List<DivisioEntity> GetAllDivisions()
        {

            List<DivisioEntity> llista = new List<DivisioEntity>();
            try
            {
                var consulta = (from d in dc.Divisions
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    DivisioEntity obj = new DivisioEntity();
                    obj.ID_Divisio = d.ID_Divisio;
                    obj.Nom_Divisio = d.Nom_Divisio;
                    obj.Descripcio = d.Descripcio;
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar totes les Divisions", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }

    }
}
