﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class EmpresaCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

        /// <summary>
        /// Comprovem Existencia Empresa
        /// </summary>
        /// <param name="ID_Empresa"></param>
        /// <returns></returns>
        public Boolean existeixEmpresa(int ID_Empresa)
        {
            try
            {
                var consulta = (from d in dc.Empreses
                                where d.ID_Empresa.Equals(ID_Empresa)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix la Empresa", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Busquem una Empresa
        /// </summary>
        /// <param name="ID_Empresa"></param>
        /// <returns></returns>
        public EmpresaEntity buscarEmpresa(int ID_Empresa)
        {
            try
            {
                var consulta = (from d in dc.Empreses
                                where d.ID_Empresa.Equals(ID_Empresa)
                                select d).Single();

                EmpresaEntity obj = new EmpresaEntity();
                obj.ID_Empresa = consulta.ID_Empresa;
                obj.Nom_Empresa = consulta.Nom_Empresa;
                obj.Logo_Empresa = (consulta.Logo_Empresa).ToArray();
                obj.Direccio = consulta.Direccio;
                obj.Poblacio = consulta.Poblacio;
                obj.CodiPostal = consulta.CodiPostal;
                obj.Provincia = consulta.Provincia;
                obj.Pais = consulta.Pais;
                obj.Telefon = consulta.Telefon;
                obj.Fax = consulta.Fax;
                obj.URL = consulta.URL;
                obj.eMail = consulta.eMail;
                return obj;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es troba l'Empresa", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Afegir una Empresa
        /// </summary>
        /// <param name="empresa"></param>
        public void insertEmpresa(EmpresaEntity empresa)
        {
            try
            {
                Empreses obj = new Empreses();
                obj.Nom_Empresa = empresa.Nom_Empresa;
                obj.Logo_Empresa = empresa.Logo_Empresa;
                obj.Direccio = empresa.Direccio;
                obj.Poblacio = empresa.Poblacio;
                obj.CodiPostal = empresa.CodiPostal;
                obj.Provincia = empresa.Provincia;
                obj.Pais = empresa.Pais;
                obj.Telefon = empresa.Telefon;
                obj.Fax = empresa.Fax;
                obj.URL = empresa.URL;
                obj.eMail = empresa.eMail;

                dc.Empreses.InsertOnSubmit(obj);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar l'Empresa", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Actualitza una Empresa
        /// </summary>
        /// <param name="empresa"></param>
        public void updateEmpresa(EmpresaEntity empresa)
        {
            var obj = (from d in dc.Empreses
                       where d.ID_Empresa == empresa.ID_Empresa
                       select d).Single();

            try
            {
                obj.Nom_Empresa = empresa.Nom_Empresa;
                obj.Logo_Empresa = empresa.Logo_Empresa;
                obj.Direccio = empresa.Direccio;
                obj.Poblacio = empresa.Poblacio;
                obj.CodiPostal = empresa.CodiPostal;
                obj.Provincia = empresa.Provincia;
                obj.Pais = empresa.Pais;
                obj.Telefon = empresa.Telefon;
                obj.Fax = empresa.Fax;
                obj.URL = empresa.URL;
                obj.eMail = empresa.eMail;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al modificar l'Empresa", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

         /// <summary>
         /// Eliminar Empresa
         /// </summary>
         /// <param name="ID_Empresa"></param>
        public void deleteEmpresaById(int ID_Empresa)
        {
            try
            {
                var consulta = (from d in dc.Empreses
                                where d.ID_Empresa == ID_Empresa
                                select d).Single();
                dc.Empreses.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar la Empresa", MessageBoxButtons.OK, MessageBoxIcon.Error);

            }
        }
    }
}
