﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class EstructuraCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

        /// <summary>
        /// Comprovem existència d'una Estructura.
        /// </summary>
        /// <param name="ID_Estructura"></param>
        /// <returns></returns>
        public Boolean existeixEstructura(int ID_Estructura)
        {
            try
            {
                var consulta = (from d in dc.Estructures
                                where d.ID_Estructura.Equals(ID_Estructura)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix la Estructura", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Llistar totes les Estructures
        /// </summary>
        /// <returns>llista</returns>
        public List<EstructuraEntity> GetAllEstructures()
        {

            List<EstructuraEntity> llista = new List<EstructuraEntity>();
            try
            {
                var consulta = (from d in dc.Estructures
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    EstructuraEntity obj = new EstructuraEntity();
                    obj.ID_Estructura = d.ID_Estructura;
                    obj.Nom_Estructura = d.Nom_Estructura;
                    obj.Descripcio = d.Descripcio;
                    obj.Estat = d.Estat;
                    obj.Data_Alta_Estruc = Convert.ToDateTime(d.Data_Alta_Estruc);
                    obj.Data_Baixa_Estruc = Convert.ToDateTime(d.Data_Baixa_Estruc);
                    obj.Qty = Convert.ToInt32(d.Qty);
                    obj.Cost = Convert.ToDecimal(d.Cost);
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar tots les Estructures", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }

        /// <summary>
        /// Llistar Estructura per:
        /// tipusConsulta = 1 per ID_Estructura
        ///                 2 per Nom_Estructura
        ///                 3 per ID_Producte
        /// </summary>
        /// <returns>llista</returns>
        public List<EstructuraEntity> llistarEstructura(int tipusConsulta, string valorBuscat)
        {
            try
            {

                List<EstructuraEntity> llista = new List<EstructuraEntity>();

                /// Per ID_Estructura

                if (tipusConsulta == 1)
                {
                    int valorn = 0;

                    var consulta = (from d in dc.Estructures
                                    where d.ID_Estructura.Equals(valorn)
                                    select d);

                    foreach (var d in consulta)
                    {
                        EstructuraEntity obj = new EstructuraEntity();
                        obj.ID_Estructura = d.ID_Estructura;
                        obj.Nom_Estructura = d.Nom_Estructura;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Estruc = Convert.ToDateTime(d.Data_Alta_Estruc);
                        obj.Data_Baixa_Estruc = Convert.ToDateTime(d.Data_Baixa_Estruc);
                        obj.Qty = Convert.ToInt32(d.Qty);
                        obj.Cost = Convert.ToDecimal(d.Cost);
                        llista.Add(obj);
                    }
                }

                /// Per nom Estructura

                if (tipusConsulta == 2)
                {
                    var consulta = (from d in dc.Estructures
                                    where (d.Nom_Estructura.Contains(valorBuscat))
                                    orderby d.Nom_Estructura
                                    select d);

                    foreach (var d in consulta)
                    {
                        EstructuraEntity obj = new EstructuraEntity();
                        obj.ID_Estructura = d.ID_Estructura;
                        obj.Nom_Estructura = d.Nom_Estructura;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Estruc = Convert.ToDateTime(d.Data_Alta_Estruc);
                        obj.Data_Baixa_Estruc = Convert.ToDateTime(d.Data_Baixa_Estruc);
                        obj.Qty = Convert.ToInt32(d.Qty);
                        obj.Cost = Convert.ToDecimal(d.Cost);
                        llista.Add(obj);
                    }
                }

                /// Per ID_Producte to DO...

                /*if (tipusConsulta == 3)
                {


                    var consulta = (from d in dc.Estructures
                                    where (d.ID_Producte.Equals(valorBuscat))
                                    orderby d.ID_Producte
                                    select d);

                    foreach (var d in consulta)
                    {
                        EstructuraEntity obj = new EstructuraEntity();
                        obj.ID_Estructura = d.ID_Estructura;
                        obj.Nom_Estructura = d.Nom_Estructura;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Estruc = Convert.ToDateTime(d.Data_Alta_Estruc);
                        obj.Data_Baixa_Estruc = Convert.ToDateTime(d.Data_Baixa_Estruc);
                        obj.Qty = Convert.ToInt32(d.Qty);
                        obj.Cost = Convert.ToDecimal(d.Cost);
                        
                        llista.Add(obj);
                    }
                }*/

                return llista;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error en llistar filtrat", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Inserta Estructura
        /// </summary>
        /// <param name="estructura"></param>
        public void insertEstructura(EstructuraEntity estructura)
        {
            try
            {
                Estructures obj = new Estructures();
                //obj.ID_Estructura = estructura.ID_Estructura; automatic
                obj.Nom_Estructura = estructura.Nom_Estructura;
                obj.Descripcio = estructura.Descripcio;
                obj.Estat = estructura.Estat;
                obj.Data_Alta_Estruc = Convert.ToDateTime(estructura.Data_Alta_Estruc);
                obj.Data_Baixa_Estruc = Convert.ToDateTime(estructura.Data_Baixa_Estruc);
                obj.Qty = estructura.Qty;
                obj.Cost = estructura.Cost;

                dc.Estructures.InsertOnSubmit(obj);
                dc.SubmitChanges();

            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar la Estructura", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Esborra Estructura
        /// </summary>
        /// <param name="ID_Estructura"></param>
        public void deleteEstructuraById(int ID_Estructura)
        {
            try
            {
                var consulta = (from d in dc.Estructures
                                where d.ID_Estructura == ID_Estructura
                                select d).Single();
                dc.Estructures.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar la Estructura", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        /// <summary>
        /// Actualitza Estructura
        /// </summary>
        /// <param name="estructura"></param>
        public void updateEstructura(EstructuraEntity estructura)
        {
            var obj = (from d in dc.Estructures
                       where d.ID_Estructura == estructura.ID_Estructura
                       select d).Single();

            try
            {
                //obj.ID_Estructura = estructura.ID_Estructura; automatic
                obj.Nom_Estructura = estructura.Nom_Estructura;
                obj.Descripcio = estructura.Descripcio;
                obj.Estat = estructura.Estat;
                obj.Data_Alta_Estruc = Convert.ToDateTime(estructura.Data_Alta_Estruc);
                obj.Data_Baixa_Estruc = Convert.ToDateTime(estructura.Data_Baixa_Estruc);
                obj.Qty = estructura.Qty;
                obj.Cost = estructura.Cost;
                
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al modificar la Estructura", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
