﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class FamiliaCN
    {
        public static bool result;
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

        /// <summary>
        /// Comprovem existència d'una Familia
        /// </summary>
        /// <param name="ID_Familia"></param>
        /// <returns></returns>
        public Boolean existeixFamilia(int ID_Familia)
        {
            try
            {
                var consulta = (from d in dc.Families
                                where d.ID_Divisio.Equals(ID_Familia)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix la Familia", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Busquem una Familia
        /// </summary>
        /// <param name="ID_Familia"></param>
        /// <returns></returns>
        public FamiliaEntity buscarFamilia(int ID_Familia)
        {
            try
            {
                var consulta = (from d in dc.Families
                                where d.ID_Divisio.Equals(ID_Familia)
                                select d).Single();

                FamiliaEntity obj = new FamiliaEntity();
                obj.ID_Familia = consulta.ID_Familia;
                obj.Nom_Familia = consulta.Nom_Familia;
                obj.ID_Divisio = consulta.ID_Divisio;
                return obj;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es troba la Familia buscada", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Afegir una Familia
        /// </summary>
        /// <param name="familia"></param>
        public void insertFamilia(FamiliaEntity familia)
        {
            try
            {
                Families obj = new Families();
                // obj.ID_Familia = familia.ID_Familia; automatic
                obj.Nom_Familia = familia.Nom_Familia;
                obj.ID_Divisio = familia.ID_Divisio;

                dc.Families.InsertOnSubmit(obj);
                dc.SubmitChanges();
                
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar la Familia", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
             
        }

        /// <summary>
        /// Actualitza una Familia
        /// </summary>
        /// <param name="familia"></param>
        public void updateFamilia(FamiliaEntity familia)
        {
            var obj = (from d in dc.Families
                       where d.ID_Familia == familia.ID_Familia
                       select d).Single();

            try
            {
                // obj.ID_Familia = familia.ID_Familia; automatic
                obj.Nom_Familia = familia.Nom_Familia;
                obj.ID_Divisio = familia.ID_Divisio;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al actualitzar la Familia", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Eliminar Familia
        /// </summary>
        /// <param name="ID_Familia"></param>
        public void deletFamiliaById(int ID_Familia)
        {
            try
            {
                var consulta = (from d in dc.Families
                                where d.ID_Familia == ID_Familia
                                select d).Single();
                dc.Families.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar la Familia", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Llistar totes les Families
        /// </summary>
        /// <returns>llista</returns>
        public List<FamiliaEntity> GetAllFamilies()
        {

            List<FamiliaEntity> llista = new List<FamiliaEntity>();
            try
            {
                var consulta = (from d in dc.Families
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    FamiliaEntity obj = new FamiliaEntity();
                    obj.ID_Familia = d.ID_Familia;
                    obj.Nom_Familia = d.Nom_Familia;
                    obj.ID_Divisio= d.ID_Divisio;
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar totes les Families", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }
    }
}
