﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class OperacioCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

        /// <summary>
        /// Comprovem existència d'una Operacio.
        /// </summary>
        /// <param name="ID_Operacio"></param>
        /// <returns></returns>
        public Boolean existeixOperacio(int ID_Operacio)
        {
            try
            {
                var consulta = (from d in dc.Operacions
                                where d.ID_Operacio.Equals(ID_Operacio)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix la Operacio", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Llistar totes les Operacions
        /// </summary>
        /// <returns>llista</returns>
        public List<OperacioEntity> GetAllOperacions()
        {

            List<OperacioEntity> llista = new List<OperacioEntity>();
            try
            {
                var consulta = (from d in dc.Operacions
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    OperacioEntity obj = new OperacioEntity();
                    obj.ID_Operacio = d.ID_Operacio;
                    obj.Nom_Operacio = d.Nom_Operacio;
                    obj.Descripcio = d.Descripcio;
                    obj.Estat = d.Estat;
                    obj.Data_Alta_Oper = Convert.ToDateTime(d.Data_Alta_Oper);
                    obj.Data_Baixa_Oper = Convert.ToDateTime(d.Data_Baixa_Oper);
                    obj.ID_Estructura = d.ID_Estructura;
                    obj.Cost = Convert.ToDecimal(d.Cost);
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar totes les Operacions", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }

        /// <summary>
        /// Llistar Operacions per:
        /// tipusConsulta = 1 per ID_Operacio
        ///                 2 per Nom_Operacio
        ///                 3 per ID_Estructura
        /// </summary>
        /// <returns>llista</returns>

        public List<OperacioEntity> llistarOperacio(int tipusConsulta, string valorBuscat)
        {
            try
            {

                List<OperacioEntity> llista = new List<OperacioEntity>();

                /// Per ID_Operacio

                if (tipusConsulta == 1)
                {
                    int valorn = 0;

                    var consulta = (from d in dc.Operacions
                                    where d.ID_Operacio.Equals(valorn)
                                    select d);

                    foreach (var d in consulta)
                    {
                        OperacioEntity obj = new OperacioEntity();
                        obj.ID_Operacio = d.ID_Operacio;
                        obj.Nom_Operacio = d.Nom_Operacio;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Oper = Convert.ToDateTime(d.Data_Alta_Oper);
                        obj.Data_Baixa_Oper = Convert.ToDateTime(d.Data_Baixa_Oper);
                        obj.ID_Estructura = d.ID_Estructura;
                        obj.Cost = Convert.ToDecimal(d.Cost);
                        llista.Add(obj);
                    }
                }

                /// Per nom Operacio

                if (tipusConsulta == 2)
                {
                    var consulta = (from d in dc.Operacions
                                    where (d.Nom_Operacio.Contains(valorBuscat))
                                    orderby d.Nom_Operacio
                                    select d);

                    foreach (var d in consulta)
                    {
                        OperacioEntity obj = new OperacioEntity();
                        obj.ID_Operacio = d.ID_Operacio;
                        obj.Nom_Operacio = d.Nom_Operacio;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Oper = Convert.ToDateTime(d.Data_Alta_Oper);
                        obj.Data_Baixa_Oper = Convert.ToDateTime(d.Data_Baixa_Oper);
                        obj.ID_Estructura = d.ID_Estructura;
                        obj.Cost = Convert.ToDecimal(d.Cost);
                        llista.Add(obj);
                    }
                }

                /// Per ID_Estructura

                if (tipusConsulta == 3)
                {


                    var consulta = (from d in dc.Operacions
                                    where (d.ID_Estructura.Equals(valorBuscat))
                                    orderby d.ID_Estructura
                                    select d);

                    foreach (var d in consulta)
                    {
                        OperacioEntity obj = new OperacioEntity();
                        obj.ID_Operacio = d.ID_Operacio;
                        obj.Nom_Operacio = d.Nom_Operacio;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Oper = Convert.ToDateTime(d.Data_Alta_Oper);
                        obj.Data_Baixa_Oper = Convert.ToDateTime(d.Data_Baixa_Oper);
                        obj.ID_Estructura = d.ID_Estructura;
                        obj.Cost = Convert.ToDecimal(d.Cost);
                        llista.Add(obj);
                    }
                }

                return llista;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error en llistar filtrat", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Procediment inserció Operacio
        /// </summary>
        /// <param name="operacio"></param>
        public void insertOperacio(OperacioEntity operacio)
        {
            try
            {
                Operacions obj = new Operacions();
                //obj.ID_Operacio=operacio.ID_Operacio; automatic
                obj.Nom_Operacio = operacio.Nom_Operacio;
                obj.Descripcio = operacio.Descripcio;
                obj.Estat = operacio.Estat;
                obj.Data_Alta_Oper = operacio.Data_Alta_Oper;
                obj.Data_Baixa_Oper = operacio.Data_Baixa_Oper;
                obj.ID_Estructura = operacio.ID_Estructura;
                obj.Cost = operacio.Cost;

                dc.Operacions.InsertOnSubmit(obj);
                dc.SubmitChanges();


            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar la Operacio", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Procediment esborrat operacio per ID
        /// </summary>
        /// <param name="ID_Operacio"></param>
        public void deleteOperacioById(int ID_Operacio)
        {
            try
            {
                var consulta = (from d in dc.Operacions
                                where d.ID_Operacio == ID_Operacio
                                select d).Single();
                dc.Operacions.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar la Operacio", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Procediment per actualitzar Operacio
        /// </summary>
        /// <param name="operacio"></param>
        public void updateOperacio(OperacioEntity operacio)
        {
            var obj = (from d in dc.Operacions
                       where d.ID_Operacio == operacio.ID_Operacio
                       select d).Single();

            try
            {
                //obj.ID_Operacio=operacio.ID_Operacio; automatic
                obj.Nom_Operacio = operacio.Nom_Operacio;
                obj.Descripcio = operacio.Descripcio;
                obj.Estat = operacio.Estat;
                obj.Data_Alta_Oper = operacio.Data_Alta_Oper;
                obj.Data_Baixa_Oper = operacio.Data_Baixa_Oper;
                obj.ID_Estructura = operacio.ID_Estructura;
                obj.Cost = operacio.Cost;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al modificar la Operacio", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
