﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class PerfilCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

        /// <summary>
        /// Comprovem existència d'un Perfil
        /// </summary>
        /// <param name="ID_Perfil"></param>
        /// <returns></returns>
        public Boolean existeixPerfil(int ID_Perfil)
        {
            try
            {
                var consulta = (from d in dc.Perfils
                                where d.ID_Perfil.Equals(ID_Perfil)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix el Perfil", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Busquem un Perfil
        /// </summary>
        /// <param name="ID_Perfil"></param>
        /// <returns></returns>
        public PerfilEntity buscarPerfil(int ID_Perfil)
        {
            try
            {
                var consulta = (from d in dc.Perfils
                                where d.ID_Perfil.Equals(ID_Perfil)
                                select d).Single();

                PerfilEntity obj = new PerfilEntity();
                obj.ID_Perfil = consulta.ID_Perfil;
                obj.TipusPerfil = consulta.TipusPerfil;
                return obj;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es troba el Perfil buscat", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Afegir un Perfil
        /// </summary>
        /// <param name="perfil"></param>
        public void insertPerfil(PerfilEntity perfil)
        {
            try
            {
                Perfils obj = new Perfils();
                obj.ID_Perfil = perfil.ID_Perfil;
                obj.TipusPerfil = perfil.TipusPerfil;

                dc.Perfils.InsertOnSubmit(obj);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar el Perfil", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Actualitza un Perfil
        /// </summary>
        /// <param name="perfil"></param>
        public void updatePerfil(PerfilEntity perfil)
        {
            var obj = (from d in dc.Perfils
                       where d.ID_Perfil == perfil.ID_Perfil
                       select d).Single();

            try
            {
                obj.ID_Perfil = perfil.ID_Perfil;
                obj.TipusPerfil = perfil.TipusPerfil;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al actualitzar el Perfil", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        ///  Eliminar Perfil
        /// </summary>
        /// <param name="ID_Perfil"></param>
        public void deletPerfilByID(int ID_Perfil)
        {
            try
            {
                var consulta = (from d in dc.Perfils
                                where d.ID_Perfil == ID_Perfil
                                select d).Single();
                dc.Perfils.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar el Perfil", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Llistar tots els Perfils
        /// </summary>
        /// <returns>llista</returns>
        public List<PerfilEntity> GetAllPerfils()
        {

            List<PerfilEntity> llista = new List<PerfilEntity>();
            try
            {
                var consulta = (from d in dc.Perfils
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    PerfilEntity obj = new PerfilEntity();
                    obj.ID_Perfil = d.ID_Perfil;
                    obj.TipusPerfil = d.TipusPerfil;
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar tots els Perfils", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }
        /// <summary>
        /// LListar els perfils segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns>
        public List<PerfilEntity> llistarPerfil(int tipusConsulta, string valorBuscat)
        {
            try
            {

                List<PerfilEntity> llista = new List<PerfilEntity>();

                /// Per ID
                
                if (tipusConsulta == 1)
                {
                    int valorn = 0;
                    valorn = Convert.ToInt32(valorBuscat);
                    var consulta = (from d in dc.Perfils
                                    where d.ID_Perfil.Equals(valorn)
                                    select d);

                    foreach (var d in consulta)
                    {
                        PerfilEntity obj = new PerfilEntity();
                        obj.ID_Perfil = d.ID_Perfil;
                        obj.TipusPerfil = d.TipusPerfil;
                        llista.Add(obj);
                    }
                }

                ///Per Tipus Perfil

                if (tipusConsulta == 2)
                {
                    var consulta = (from d in dc.Perfils
                                    where (d.TipusPerfil.Contains(valorBuscat))
                                    orderby d.TipusPerfil
                                    select d);

                    foreach (var d in consulta)
                    {
                        PerfilEntity obj = new PerfilEntity();
                        obj.ID_Perfil = d.ID_Perfil;
                        obj.TipusPerfil = d.TipusPerfil;
                        llista.Add(obj);
                    }
                }

                return llista;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error en llistar Perfils filtrat", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }


    }
}
