﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
   
    public class PersonaCN
    {
       
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

      /// <summary>
      /// Comprovem Existencia PErsona
      /// </summary>
      /// <param name="ID_Persona"></param>
      /// <returns></returns>
        public Boolean existeixPersona(int ID_Persona)
        {
            try
            {
                var consulta = (from d in dc.Persones
                                where d.ID_Persona.Equals(ID_Persona)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix la Persona", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

      /// <summary>
      /// Busquem una Persona
      /// </summary>
      /// <param name="DNI"></param>
      /// <returns></returns>
        public PersonaEntity buscarPersona(string DNI)
        {
            try
            {
                var consulta = (from d in dc.Persones
                                where d.DNI.Equals(DNI)
                                select d).Single();

                PersonaEntity obj = new PersonaEntity();
                obj.ID_Persona = consulta.ID_Persona;
                obj.DNI = consulta.DNI; 
                obj.Nom = consulta.Nom;
                obj.Cognom1 = consulta.Cognom1;
                obj.Cognom2 = consulta.Cognom2;
                obj.Direccio = consulta.Direccio;
                obj.Poblacio = consulta.Poblacio;
                obj.CodiPostal = consulta.CodiPostal;
                obj.Provincia = consulta.Provincia;
                obj.Pais = consulta.Pais;
                obj.Telefon = consulta.Telefon;
                obj.eMail = consulta.eMail;
                obj.DataAlta = Convert.ToDateTime(consulta.DataAlta);
                obj.DataBaixa = Convert.ToDateTime(consulta.DataBaixa);
                obj.ID_Perfil = Convert.ToInt32(consulta.ID_Perfil);
                obj.Contrasenya = consulta.Contrasenya;
                obj.Actiu = consulta.Actiu;
                
                return obj;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es troba la Persona", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Busquem una Persona
        /// </summary>
        /// <param name="DNI"></param>
        /// <returns></returns>
        public PersonaEntity buscarPersonaId(int ID_Persona)
        {
            try
            {
                var consulta = (from d in dc.Persones
                                where d.ID_Persona.Equals(ID_Persona)
                                select d).Single();

                PersonaEntity obj = new PersonaEntity();
                obj.ID_Persona = consulta.ID_Persona;
                obj.DNI = consulta.DNI;
                obj.Nom = consulta.Nom;
                obj.Cognom1 = consulta.Cognom1;
                obj.Cognom2 = consulta.Cognom2;
                obj.Direccio = consulta.Direccio;
                obj.Poblacio = consulta.Poblacio;
                obj.CodiPostal = consulta.CodiPostal;
                obj.Provincia = consulta.Provincia;
                obj.Pais = consulta.Pais;
                obj.Telefon = consulta.Telefon;
                obj.eMail = consulta.eMail;
                obj.DataAlta = Convert.ToDateTime(consulta.DataAlta);
                obj.DataBaixa = Convert.ToDateTime(consulta.DataBaixa);
                obj.ID_Perfil = Convert.ToInt32(consulta.ID_Perfil);
                obj.Contrasenya = consulta.Contrasenya;
                obj.Actiu = consulta.Actiu;
                
                return obj;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es troba la Persona per ID", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }


       /// <summary>
       /// Afegir una Persona
       /// </summary>
       /// <param name="persona"></param>
        public void insertPersona(PersonaEntity persona)
        {
            try
            {
                Persones obj = new Persones();
                obj.DNI = persona.DNI;
                obj.Nom = persona.Nom;
                obj.Cognom1 = persona.Cognom1;
                obj.Cognom2 = persona.Cognom2;
                obj.Direccio = persona.Direccio;
                obj.Poblacio = persona.Poblacio;
                obj.CodiPostal = persona.CodiPostal;
                obj.Provincia = persona.Provincia;
                obj.Pais = persona.Pais;
                obj.Telefon = persona.Telefon;
                obj.eMail = persona.eMail;
                obj.DataAlta = persona.DataAlta;
                if (isDateNull(persona.DataBaixa) == false)
                {
                    obj.DataBaixa = persona.DataBaixa;
                }
                obj.ID_Perfil = persona.ID_Perfil;
                obj.Contrasenya = persona.Contrasenya;
                obj.Actiu = persona.Actiu;
                
                dc.Persones.InsertOnSubmit(obj);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar la Persona", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

       /// <summary>
        /// Actualitza una Persona
       /// </summary>
       /// <param name="persona"></param>
        public void updatePersona(PersonaEntity persona)
        {
            var obj = (from d in dc.Persones
                       where d.ID_Persona == persona.ID_Persona
                       select d).Single();

            try
            {
                obj.DNI = persona.DNI;
                obj.Nom = persona.Nom;
                obj.Cognom1 = persona.Cognom1;
                obj.Cognom2 = persona.Cognom2;
                obj.Direccio = persona.Direccio;
                obj.Poblacio = persona.Poblacio;
                obj.CodiPostal = persona.CodiPostal;
                obj.Provincia = persona.Provincia;
                obj.Pais = persona.Pais;
                obj.Telefon = persona.Telefon;
                obj.eMail = persona.eMail;
                obj.DataAlta = persona.DataAlta;
                if (isDateNull(persona.DataBaixa) == false)
                {
                    obj.DataBaixa = persona.DataBaixa;
                }
                obj.ID_Perfil = persona.ID_Perfil;
                obj.Contrasenya = persona.Contrasenya;
                obj.Actiu = persona.Actiu;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al modificar la Persona", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Canvi d'estat Actiu d'una Persona
        /// </summary>
        /// <param name="DNI"></param>
        /// <param name="actiu"></param>
        /// <returns></returns>
        public bool updateActiu(string DNI, bool actiu)
        {
            try
            {
                PersonaEntity persona = buscarPersona(DNI);

                persona.Actiu = actiu;
                updatePersona(persona);
            }
            catch (Exception)
            {
                return false;
            }


            return true;
        }

        /// <summary>
        /// Eliminar PErsona
        /// </summary>
        /// <param name="ID_Persona"></param>
        public void deletPersonaByID(int ID_Persona)
        {
            try
            {
                var consulta = (from d in dc.Persones
                             where d.ID_Persona == ID_Persona
                             select d).Single();
                dc.Persones.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar la Persona", MessageBoxButtons.OK, MessageBoxIcon.Error);
   
            }

 
        }

        /// <summary>
        /// Llistar totes les Persones 
        /// </summary>
        /// <returns>llista</returns>
        public List<PersonaEntity> GetAllPersones()
        {

            List<PersonaEntity> llista = new List<PersonaEntity>();
            try
            {
                var consulta = (from d in dc.Persones
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    PersonaEntity obj = new PersonaEntity();
                    obj.ID_Persona = d.ID_Persona;
                    obj.DNI = d.DNI;
                    obj.Nom = d.Nom;
                    obj.Cognom1 = d.Cognom1;
                    obj.Cognom2 = d.Cognom2;
                    obj.Direccio = d.Direccio;
                    obj.Poblacio = d.Poblacio;
                    obj.CodiPostal = d.CodiPostal;
                    obj.Provincia = d.Provincia;
                    obj.Pais = d.Pais;
                    obj.Telefon = d.Telefon;
                    obj.eMail = d.eMail;
                    obj.DataAlta = Convert.ToDateTime( d.DataAlta);
                    obj.DataBaixa = Convert.ToDateTime(d.DataBaixa);
                    obj.ID_Perfil = Convert.ToInt32( d.ID_Perfil);
                    obj.Contrasenya = d.Contrasenya;
                    obj.Actiu = d.Actiu;
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar totes les Persones", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }


        /// <summary>
        /// Llistar Persones per:
        /// tipusConsulta = 1 per ID_Persona
        ///                 2 per DNI
        ///                 3 per Nom
        /// </summary>
        /// <returns>llista</returns>

        public List<PersonaEntity> llistarPersona(int tipusConsulta, string valorBuscat)
        {
            try
            {

                List<PersonaEntity> llista = new List<PersonaEntity>();

                /// Per ID_Persona

                if (tipusConsulta == 1)
                {
                    int valorn = 0;
                    valorn = Convert.ToInt32(valorBuscat);
                    var consulta = (from d in dc.Persones
                                    where d.ID_Persona.Equals(valorn)
                                    select d);

                    foreach (var d in consulta)
                    {
                        PersonaEntity obj = new PersonaEntity();
                        obj.DNI = d.DNI;
                        obj.Nom = d.Nom;
                        obj.Cognom1 = d.Cognom1;
                        obj.Cognom2 = d.Cognom2;
                        llista.Add(obj);
                    }
                }

                if (tipusConsulta == 2)
                {
                    var consulta = (from d in dc.Persones
                                    where (d.DNI.Contains(valorBuscat))
                                    orderby d.DNI
                                    select d);

                    foreach (var d in consulta)
                    {
                        PersonaEntity obj = new PersonaEntity();
                        obj.DNI = d.DNI;
                        obj.Nom = d.Nom;
                        obj.Cognom1 = d.Cognom1;
                        obj.Cognom2 = d.Cognom2;
                        llista.Add(obj);
                    }
                }

                if (tipusConsulta == 3)
                {
                    
                    var consulta = (from d in dc.Persones
                                    where (d.Nom.Contains(valorBuscat))
                                    orderby d.DNI
                                    select d);

                    foreach (var d in consulta)
                    {
                        PersonaEntity obj = new PersonaEntity();
                        obj.DNI = d.DNI;
                        obj.Nom = d.Nom;
                        obj.Cognom1 = d.Cognom1;
                        obj.Cognom2 = d.Cognom2;
                        llista.Add(obj);
                    }
                }

                return llista;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error en llistar filtrat", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Validar el login de la Persona mitjan
        /// </summary>
        /// <param name="DNI"></param>
        /// <param name="contrasenya"></param>
        /// <returns></returns>
        public int validarLoginPersona(string DNI, string contrasenya)
        {
            try
            {
                
                ///
                ///Validem el login de la PErsona per el seu DNI
                ///
                
                    int id_persona = Convert.ToInt32(DNI);
                    var query = (from d in dc.Persones
                                 where d.DNI == DNI && d.Contrasenya == contrasenya
                                 select d);

                    if (query.Count() != 0) 
                    {
                        return query.First().ID_Persona;
                    }
                    else
                    {
                        return 0;
                    }         

            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al validar login Persona", MessageBoxButtons.OK, MessageBoxIcon.Error); return 0;
            }
        }

        /// <summary>
        /// Canvi Contrasenya PErsona WEB 
        /// </summary>
        /// <param name="id_Persona"></param>
        /// <param name="contrasenya"></param>
        public void canviContrasenyaPersonaWeb(int id_Persona, string contrasenya)
        {
            var obj = (from d in dc.Persones
                       where d.ID_Persona == id_Persona
                       select d).Single();

            try
            {
                obj.Contrasenya = contrasenya;
                dc.SubmitChanges();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error modificant contrasenya Persona Web", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Validar Numero  
        /// </summary>
        /// <param name="numero"></param>
        /// <returns></returns>
        private Boolean isNumeric(string numero)
        {
            int number = 0;
            if (int.TryParse(numero.Trim(), out number)) return true;
            return false;
        }

        /// <summary>
        /// Comprovem si la data es null
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        private Boolean isDateNull(DateTime data)
        {
            if (data.ToString("dd/MM/yyyy") == "01/01/0001")
            {
                return true;
            }
            else
            {
                return false;
            }
        }


    }
}
