﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;



namespace ERPProduction.Negoci
{
    public class ProducteCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

       /// <summary>
        /// Comprovem existència d'un Producte
       /// </summary>
       /// <param name="ID_Producte"></param>
       /// <returns></returns>
        public Boolean existeixProducte(int ID_Producte)
        {
            try
            {
                var consulta = (from d in dc.Productes
                                where d.ID_Producte.Equals(ID_Producte)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix el Producte", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Llistar tots els Productes 
        /// </summary>
        /// <returns>llista</returns>
        public List<ProducteEntity> GetAllProductes()
        {

            List<ProducteEntity> llista = new List<ProducteEntity>();
            try
            {
                var consulta = (from d in dc.Productes
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    ProducteEntity obj = new ProducteEntity();
                    obj.ID_Producte = d.ID_Producte;
                    obj.Nom_Producte = d.Nom_Producte;
                    obj.Descripcio = d.Descripcio;
                    obj.Estat = d.Estat;
                    obj.Data_Alta_Producte = Convert.ToDateTime(d.Data_Alta_Producte);
                    obj.Data_Baixa_Producte = Convert.ToDateTime(d.Data_Baixa_Producte);
                    /*obj.Foto_Producte = (d.Foto_Producte).ToArray();*/
                    obj.ID_Familia = d.ID_Familia;
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar tots els Productes", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }

        /// <summary>
        /// Llistar Producte per:
        /// tipusConsulta = 1 per ID_Producte
        ///                 2 per Nom
        ///                 3 per ID_Familia
        /// </summary>
        /// <returns>llista</returns>
        public List<ProducteEntity> llistarProducte(int tipusConsulta, string valorBuscat)
        {
            try
            {

                List<ProducteEntity> llista = new List<ProducteEntity>();

                /// Per ID_Producte

                if (tipusConsulta == 1)
                {
                    int valorn = 0;
                   
                    var consulta = (from d in dc.Productes
                                    where d.ID_Producte.Equals(valorn)
                                    select d);

                    foreach (var d in consulta)
                    {
                        ProducteEntity obj = new ProducteEntity();
                        obj.ID_Producte = d.ID_Producte;
                        obj.Nom_Producte = d.Nom_Producte;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Producte = Convert.ToDateTime(d.Data_Alta_Producte);
                        obj.Data_Baixa_Producte = Convert.ToDateTime(d.Data_Baixa_Producte);
                        /*obj.Foto_Producte = (d.Foto_Producte).ToArray();*/
                        obj.ID_Familia = d.ID_Familia;
                        llista.Add(obj);
                    }
                }

                /// Per NOm
                if (tipusConsulta == 2)
                {
                    var consulta = (from d in dc.Productes
                                    where (d.Nom_Producte.Contains(valorBuscat))
                                    orderby d.Nom_Producte
                                    select d);

                    foreach (var d in consulta)
                    {
                        ProducteEntity obj = new ProducteEntity();
                        obj.ID_Producte = d.ID_Producte;
                        obj.Nom_Producte = d.Nom_Producte;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Producte = Convert.ToDateTime(d.Data_Alta_Producte);
                        obj.Data_Baixa_Producte = Convert.ToDateTime(d.Data_Baixa_Producte);
                        /*obj.Foto_Producte = (d.Foto_Producte).ToArray();*/
                        obj.ID_Familia = d.ID_Familia;
                        llista.Add(obj);
                    }
                }

                /// Per ID_Familia
                if (tipusConsulta == 3)
                {

                   
                    var consulta = (from d in dc.Productes
                                    where (d.ID_Familia.Equals(valorBuscat))
                                    orderby d.ID_Familia
                                    select d);

                    foreach (var d in consulta)
                    {
                        ProducteEntity obj = new ProducteEntity();
                        obj.ID_Producte = d.ID_Producte;
                        obj.Nom_Producte = d.Nom_Producte;
                        obj.Descripcio = d.Descripcio;
                        obj.Estat = d.Estat;
                        obj.Data_Alta_Producte = Convert.ToDateTime(d.Data_Alta_Producte);
                        obj.Data_Baixa_Producte = Convert.ToDateTime(d.Data_Baixa_Producte);
                        /*obj.Foto_Producte = (d.Foto_Producte).ToArray();*/
                        obj.ID_Familia = d.ID_Familia;
                        llista.Add(obj);
                    }
                }

                return llista;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error en llistar filtrat", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;
            }
        }

        /// <summary>
        /// Insertar Producte
        /// </summary>
        /// <param name="producte"></param>
        public void insertProducte(ProducteEntity producte)
        { try
            {
                Productes obj = new Productes();
                obj.ID_Producte = producte.ID_Producte;
                obj.Nom_Producte = producte.Nom_Producte;               
                obj.Descripcio = producte.Descripcio;
                obj.Estat = producte.Estat;
                obj.Data_Alta_Producte = Convert.ToDateTime(producte.Data_Alta_Producte);
                obj.Data_Baixa_Producte = Convert.ToDateTime(producte.Data_Baixa_Producte);
                /*obj.Foto_Producte = producte.Foto_Producte;*/
                obj.ID_Familia = producte.ID_Familia;

                dc.Productes.InsertOnSubmit(obj);
                dc.SubmitChanges();

            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar el Producte", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Esborrar Producte
        /// </summary>
        /// <param name="ID_Producte"></param>
        public void deleteProducteById(int ID_Producte)
        {
            try
            {
                var consulta = (from d in dc.Productes
                                where d.ID_Producte == ID_Producte
                                select d).Single();
                dc.Productes.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar el Producte", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        /// <summary>
        /// Actualitzar Producte
        /// </summary>
        /// <param name="producte"></param>
        public void updateProducte(ProducteEntity producte)
        {
            var obj = (from d in dc.Productes
                       where d.ID_Producte == producte.ID_Producte
                       select d).Single();

            try
            {
                obj.ID_Producte = producte.ID_Producte;
                obj.Nom_Producte = producte.Nom_Producte;
                obj.Descripcio = producte.Descripcio;
                obj.Estat = producte.Estat;
                obj.Data_Alta_Producte = Convert.ToDateTime(producte.Data_Alta_Producte);
                obj.Data_Baixa_Producte = Convert.ToDateTime(producte.Data_Baixa_Producte);
                /*obj.Foto_Producte = producte.Foto_Producte;*/
                obj.ID_Familia = producte.ID_Familia;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al modificar el Producte", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
