﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using System.Windows.Forms;
using System.Globalization;
using ERPProduction.AccessDB;
using ERPProduction.NegociEntitats;

namespace ERPProduction.Negoci
{
    public class TipusComponentsCN
    {
        /// <summary>
        /// Connexió amb les classes de modelització de la BD
        /// </summary>
        ERPProductionDataClassesDataContext dc = new ERPProductionDataClassesDataContext();

        /// <summary>
        ///  Comprovem existència d'un Tipus de Component.
        /// </summary>
        /// <param name="ID_Tipus_Compo"></param>
        /// <returns></returns>
        public Boolean existeixTipusCompo(int ID_Tipus_Compo)
        {
            try
            {
                var consulta = (from d in dc.TipusComponents
                                where d.ID_Tipus_Compo.Equals(ID_Tipus_Compo)
                                select d);

                if (consulta.Count() == 0) return false;
                return true;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error No existeix el Tipus de Component", MessageBoxButtons.OK, MessageBoxIcon.Error); return false;
            }
        }

        /// <summary>
        /// Llistar tots els Tipus de Components
        /// </summary>
        /// <returns>llista</returns>
        public List<TipusComponentsEntity> GetAllTipusCompo()
        {

            List<TipusComponentsEntity> llista = new List<TipusComponentsEntity>();
            try
            {
                var consulta = (from d in dc.TipusComponents
                                where true
                                select d);

                foreach (var d in consulta)
                {
                    TipusComponentsEntity obj = new TipusComponentsEntity();
                    obj.ID_Tipus_Compo = d.ID_Tipus_Compo;
                    obj.Tipus_Compo = d.Tipus_Compo;
                    llista.Add(obj);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al llistar tots els Tipus de Components", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            return llista;
        }

        /// <summary>
        /// Afegir Tipus Component
        /// </summary>
        /// <param name="tipusCompo"></param>
        public void insertTipusCompo(TipusComponentsEntity tipusCompo)
        {
            try
            {
                TipusComponents obj = new TipusComponents();
                //obj.ID_Tipus_Compo = tipusCompo.ID_Tipus_Compo; automatic
                obj.Tipus_Compo = tipusCompo.Tipus_Compo;

                dc.TipusComponents.InsertOnSubmit(obj);
                dc.SubmitChanges();

            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error no es pot insertar el Tipus de Component", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        
        /// <summary>
        /// Esborrar Tipus Component
        /// </summary>
        /// <param name="ID_Tipus_Compo"></param>
        public void deleteTipusCompoById(int ID_Tipus_Compo)
        {
            try
            {
                var consulta = (from d in dc.TipusComponents
                                where d.ID_Tipus_Compo == ID_Tipus_Compo
                                select d).Single();
                dc.TipusComponents.DeleteOnSubmit(consulta);
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al eliminar el Tipus de Component", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Actualitzar Tipus Component
        /// </summary>
        /// <param name="tipusCompo"></param>
        public void updateTipusCompo(TipusComponentsEntity tipusCompo)
        {
            var obj = (from d in dc.TipusComponents
                       where d.ID_Tipus_Compo == tipusCompo.ID_Tipus_Compo
                       select d).Single();

            try
            {
                //obj.ID_Tipus_Compo = tipusCompo.ID_Tipus_Compo; automatic
                obj.Tipus_Compo = tipusCompo.Tipus_Compo;
                dc.SubmitChanges();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Error al modificar el Tipus de Component", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

    }
}
