﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Reflection;
using System.Diagnostics;
using ERPProduction.WPF.Interface;
using ERPProduction.WPF.Util;
using ERPProduction.WPF.ServiceReference1;

namespace ERPProduction.WPF.Control
{
    /// <summary>
    /// Lógica de interacción para UCGestioComponents.xaml
    /// </summary>
    public partial class UCGestioComponents : UserControl, ISwitchable
    {
        ICollectionView Source { get; set; }

        public UCGestioComponents()
        {
            InitializeComponent();

            cmbProperty.DataContext = new List<string> {"ID", "Nom", "Descripcio", "Estat", "Alta Component", "Baixa Component", "Tipus Compo", "Estructura", "Cost"};

            updateComponents();

        }

        /// <summary>
        /// Metode intern que actualitza els Components.
        /// </summary>

        internal void updateComponents()
        {
            try
            {

                ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
                var components = servei.GetAllComponents();
                servei.Close();

                Source = CollectionViewSource.GetDefaultView(components);
                this.DataContext = CollectionViewSource.GetDefaultView(components);
            }
            catch (Exception)
            {
                Alerta.alertaError1();
            }
        }

        #region Filtre

        /// <summary>
        /// Llistar les columnes definides
        /// </summary>
        public IEnumerable<string> Columns
        {
            get
            {
                return from prop in typeof(ServiceReference1.ComponentEntity).GetProperties()
                       select prop.Name;
            }
        }

        /// <summary>
        /// Netejar Filtre
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void btnClear_Click(object sender, RoutedEventArgs e)
        {
            Source.Filter = item => true;
            txtFilter.Text = string.Empty;
            cmbProperty.Text = string.Empty;
        }

        /// <summary>
        /// Aplicar filtre de cerca per columna 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void btnFilter_Click(object sender, RoutedEventArgs e)
        {
            this.Source.Filter = item =>
            {
            ServiceReference1.ComponentEntity nitem = item as ServiceReference1.ComponentEntity;
            PropertyInfo info = item.GetType().GetProperty(cmbProperty.Text);
            if (info == null) return false;

            return info.GetValue(nitem, null).ToString().ToLower().Contains(txtFilter.Text.ToLower());
            };
          
        }



        #endregion

        #region ISwitchable Members

        void ISwitchable.UtilizeState(object state)
        {
            throw new NotImplementedException();
        }

        #endregion

        #region Accions

        /// <summary>
        /// Afegir nou Component a la BBDD.
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void Afegir_Click(object sender, RoutedEventArgs e)
        {
            Switcher.Switch(new Control.UCGestioComponentCon());

        }

        /// <summary>
        /// Editar Component de la BBDD.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Editar_Click(object sender, RoutedEventArgs e)
        {
            
        }

        /// <summary>
        /// Eliminar Component de la BBDD.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

       private void Eliminar_Click(object sender, RoutedEventArgs e)
        {
            
            Button btn =  (Button)sender;
            ComponentEntity component = ((ComponentEntity)btn.DataContext);
            int id = component.ID_Component;
            MessageBox.Show("S'eliminarà el Component: " + System.Environment.NewLine + component.ID_Component + "" + component.Nom_Component , "Eliminar Component", MessageBoxButton.OK, MessageBoxImage.Information);

            try
            {

                ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
                servei.deleteComponentById(id);
                servei.Close();
                
                Switcher.Switch(new UCGestioComponents());
                Alerta.alertaInfo(Textes.CompoElimOk);
            }
            catch (Exception)
            {
                Alerta.alertaError1();
                Alerta.alertaInfo(Textes.CompoElimNok);
            }

        }
        
        /// <summary>
        /// Informació del component seleccionat
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

       private void Info_Click(object sender, RoutedEventArgs e)
       {

       }

        /// <summary>
        /// Canvi de l'estat Actiu d'una Persona
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Actiu_Click(object sender, RoutedEventArgs e)
        {
                        

        }

        private void cmbProperty_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            txtFilter.Focus();
        }


        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {

        }

        #endregion

        private void Image_ImageFailed(object sender, ExceptionRoutedEventArgs e)
        {

        }

    }
}
