﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Reflection;
using System.Diagnostics;
using System.Data;
using System.Data.SqlClient;
using ERPProduction.WPF.Interface;
using ERPProduction.WPF.Util;
using ERPProduction.WPF.ServiceReference1;

namespace ERPProduction.WPF.Control
{
    /// <summary>
    /// Lógica de interacción para UCGestioProductes.xaml
    /// </summary>
    public partial class UCGestioProductes : UserControl, ISwitchable
    {
        ICollectionView Source { get; set; }
        public Boolean info;

        public UCGestioProductes()
        {
            InitializeComponent();

            cmbProperty.DataContext = new List<string> { "ID_Producte", "Nom_Producte","Descripcio", "Estat", "Data_Alta_Producte", "Data_Baixa_Producte", "ID_Familia"};

            updateProductes();

        }

        /// <summary>
        /// 
        /// </summary>
        internal void updateProductes()
        {
            try
            {
            ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
            var productes = servei.GetAllProductes();
            servei.Close();

            Source = CollectionViewSource.GetDefaultView(productes);
            this.DataContext = CollectionViewSource.GetDefaultView(productes);
            }
            catch (Exception)
            {
                Alerta.alertaError1();
            }
        }

        #region Filtre

        /// <summary>
        /// Llistar les columnes
        /// </summary>
        public IEnumerable<string> Columns
        {
            get
            {
                return from prop in typeof(ServiceReference1.ProducteEntity).GetProperties()
                       select prop.Name;
            }
        }

        ///
        /// Netejar Filtre
        ///

        private void btnClear_Click(object sender, RoutedEventArgs e)
        {
            Source.Filter = item => true;
            txtFilter.Text = string.Empty;
        }

        ///
        ///Aplicar Filtre
        ///

        private void btnFilter_Click(object sender, RoutedEventArgs e)
        {
            this.Source.Filter = item =>
            {
                ServiceReference1.ProducteEntity nitem = item as ServiceReference1.ProducteEntity;
                PropertyInfo info = item.GetType().GetProperty(cmbProperty.Text);
                if (info == null) return false;

                return info.GetValue(nitem, null).ToString().ToLower().Contains(txtFilter.Text.ToLower());
            };
        }
        
        #endregion

        #region ISwitchable Members

        void ISwitchable.UtilizeState(object state)
        {
            throw new NotImplementedException();
        }

        #endregion

        #region Accions

        /// <summary>
        /// Afegir nou Producte a la BBDD.
        /// Crida al UControl específic d'introducció de dades del Producte.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void Afegir_Click(object sender, RoutedEventArgs e)
        {
            string accio = "0";
            Switcher.Switch(new Control.UCGestioProductesCon(accio));

        }

        
        /// <summary>
        /// Eliminar Producte de la BBDD.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void Eliminar_Click(object sender, RoutedEventArgs e)
        {

            Button btn = (Button)sender;
            ProducteEntity producte = ((ProducteEntity)btn.DataContext);
            int id = producte.ID_Producte;
            MessageBox.Show("S'eliminarà el Producte: " + System.Environment.NewLine + producte.Nom_Producte, "Eliminar Producte", MessageBoxButton.OK, MessageBoxImage.Information);

            try
            {

                ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
                servei.deleteProducteById(id);
                servei.Close();

                Switcher.Switch(new UCGestioProductes());
                Alerta.alertaInfo(Textes.ProducteElimOk);
            }
            catch (Exception)
            {
                Alerta.alertaError1();
                Alerta.alertaInfo(Textes.ProducteElimNok);
            }

        }

        #endregion

        /// <summary>
        /// Canvi de l'estat Actiu d'una Producte
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Actiu_Click(object sender, RoutedEventArgs e)
        {


        }

        private void Editar_Click(object sender, RoutedEventArgs e)
        {

        }
        private void cmbProperty_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {

        }

        private void ListView_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {

        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {

        }

    }
}
