﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ERPProduction.WPF.ServiceReference1;
using ERPProduction.WPF.Interface;
using ERPProduction.WPF.Util;

namespace ERPProduction.WPF.Control
{
    /// <summary>
    /// Lógica de interacción para UCGestioProductesCon.xaml
    /// </summary>
    public partial class UCGestioProductesCon : UserControl,ISwitchable
    {
        /// <summary>
        /// 
        /// </summary>
        /// <param name="accio"></param>
        public UCGestioProductesCon(string accio)
        {
            InitializeComponent(); 
            selectTabByAccio(accio);

            ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
            
            updateTabProducte(servei);
            updateTabFamilia(servei);
            updateTabDivisio(servei);
            servei.Close();
            
        }

        private void selectTabByAccio(string accio)
        {
            if (!string.IsNullOrEmpty(accio))
            {
                switch (accio)
                {
                    case "producte":
                        tabControl1.SelectedIndex = 0;
                        carregarComboaProductes();
                        carregarComboaFamilies();
                        break;
                    case "familia":
                        tabControl1.SelectedIndex = 1;
                        carregarComboaProductes();
                        carregarComboaFamilies();
                        break;
                    case "divisio":
                        tabControl1.SelectedIndex = 2;
                        carregarComboaProductes();
                        carregarComboaFamilies();
                        break;
                }
            }
        }

        #region ISwitchable Members

        void ISwitchable.UtilizeState(object state)
        {
            throw new NotImplementedException();
        }

        #endregion

        #region Productes
        /// <summary>
        /// 
        /// </summary>
        /// <param name="servei"></param>
        internal void updateTabProducte(ERPProductionClient servei)
        {
            tabProductes.DataContext = CollectionViewSource.GetDefaultView(servei.GetAllProductes());
        }

        private void afegirProducte_Click(object sender, RoutedEventArgs e)
        {

        }


        #endregion

        #region Families
        /// <summary>
        /// 
        /// </summary>
        /// <param name="servei"></param>
        internal void updateTabFamilia(ERPProductionClient servei)
        {
            tabFamilies.DataContext= CollectionViewSource.GetDefaultView(servei.GetAllFamilies());
        }

        


        private void afegirFamilia_Click(object sender, RoutedEventArgs e)
        {
           
            
            if (txtBoxFamilia.Text.Trim().Equals(string.Empty))
                Alerta.alertaInfo(Textes.campNoNull);
            else
            {
                var familia = new FamiliaEntity
                {
                    Nom_Familia = txtBoxFamilia.Text.Trim(),
                    ID_Divisio = ((DivisioEntity)cboxFamilia.SelectedValue).ID_Divisio                   
                };

                try
                {
                    ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
                    servei.insertFamilia(familia);
                    updateTabFamilia(servei);
                    servei.Close();
                }
                catch (Exception)
                {
                    Alerta.alertaError1();
                }
            }
            txtBoxFamilia.Clear();          

        }

        private void deleteFamilia_Click(object sender, RoutedEventArgs e)
        {
            Button btn = (Button)sender;
            try
            {
                ERPProductionClient servei = new ERPProductionClient();
                servei.deleteFamiliaById(((FamiliaEntity)btn.DataContext).ID_Familia);
                updateTabFamilia(servei);
            }
            catch
            {
                Alerta.alertaError1();
            }
        }
        #endregion

        #region Divisions
        internal void updateTabDivisio(ERPProductionClient servei)
        {
            tabDivisio.DataContext=CollectionViewSource.GetDefaultView(servei.GetAllDivisions());
        }

        private void afegirDivisio_Click(object sender, RoutedEventArgs e)
        {
            if (txtBoxDivisio.Text.Trim().Equals(string.Empty))
                Alerta.alertaInfo(Textes.campNoNull);
            else
            {
                var divisio = new DivisioEntity
                {
                    Nom_Divisio = txtBoxDivisio.Text.Trim(),
                    Descripcio = txtBoxDivisioDes.Text.TrimEnd()
                };


                try
                {
                    ERPProductionClient servei = new ServiceReference1.ERPProductionClient();

                    servei.insertDivisio(divisio);
                    updateTabDivisio(servei);
                    servei.Close();
                }
                catch (Exception)
                {
                    Alerta.alertaError1();
                }
            }
            txtBoxDivisio.Clear();
            txtBoxDivisioDes.Clear();

        }

        private void deleteDivisio_Click(object sender, RoutedEventArgs e)
        {
            Button btn = (Button)sender;
            try
            {
                ERPProductionClient servei = new ERPProductionClient();
                servei.deleteDivisioById(((DivisioEntity)btn.DataContext).ID_Divisio);
                updateTabDivisio(servei);
               
            }
            catch
            {
                Alerta.alertaError1();
            }
        }
        #endregion

        private void carregarComboaProductes()
        {
            ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
            try
            {
                cboxFamilias.DataContext = servei.GetAllFamilies();
                servei.Close();

            }
            catch (Exception)
            {
                Alerta.alertaError1();
            }
           
        }

        private void carregarComboaFamilies()
        {
            ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
            try
            {
                cboxFamilia.DataContext = servei.GetAllDivisions();
                servei.Close();

            }
            catch (Exception)
            {
                Alerta.alertaError1();
            }

        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            
        }
    }
}
