﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Reflection;
using System.Diagnostics;
using ERPProduction.WPF.Interface;
using ERPProduction.WPF.Util;
using ERPProduction.WPF.ServiceReference1;




namespace ERPProduction.WPF.Control
{
    /// <summary>
    /// Lógica de interacción para UCGestioUsuaris.xaml
    /// </summary>
    public partial class UCGestioUsuaris : UserControl, ISwitchable
    {
        ICollectionView Source { get; set; }
        public Boolean info;

        public UCGestioUsuaris()
        {
            InitializeComponent();

            cmbProperty.DataContext = new List<string> {"DNI", "Nom", "Cognom", "Actiu" };

            updatePersones();

        }

        /// <summary>
        /// Metode intern que actualitza les Persones.
        /// </summary>
        internal void updatePersones()
        {
            try
            {

                ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
                var persones = servei.GetAllPersones();
                servei.Close();

                Source = CollectionViewSource.GetDefaultView(persones);
                this.DataContext = CollectionViewSource.GetDefaultView(persones);
            }
            catch (Exception)
            {
                Alerta.alertaError1();
            }
        }

        #region Filtre

        /// <summary>
        /// Llistar les columnes definides
        /// </summary>
        public IEnumerable<string> Columns
        {
            get
            {
                return from prop in typeof(ServiceReference1.PersonaEntity).GetProperties()
                       select prop.Name;
            }
        }

        /// <summary>
        /// Netejar Filtre
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void btnClear_Click(object sender, RoutedEventArgs e)
        {
            Source.Filter = item => true;
            txtFilter.Text = string.Empty;
            cmbProperty.Text = string.Empty;
        }

        /// <summary>
        /// Aplicar filtre de cerca per columna 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void btnFilter_Click(object sender, RoutedEventArgs e)
        {
            this.Source.Filter = item =>
            {
            ServiceReference1.PersonaEntity nitem = item as ServiceReference1.PersonaEntity;
            PropertyInfo info = item.GetType().GetProperty(cmbProperty.Text);
            if (info == null) return false;

            return info.GetValue(nitem, null).ToString().ToLower().Contains(txtFilter.Text.ToLower());
            };
          
        }



        #endregion

        #region ISwitchable Members

        void ISwitchable.UtilizeState(object state)
        {
            throw new NotImplementedException();
        }

        #endregion

        #region Accions

        /// <summary>
        /// Afegir nou Usuari o Persona a la BBDD.
        /// Crida al UControl específic d'introducció de dades del Usuari en mode Edició nou Usuari.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void Afegir_Click(object sender, RoutedEventArgs e)
        {
            Switcher.Switch(new Control.UCGestioUsuarisCon());

        }

        /// <summary>
        /// Editar Usuari o Persona de la BBDD.
        /// Crida al UControl específic d'edició de dades del Usuari en mode Edició Usuari, enviant el DNI a modificar.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Editar_Click(object sender, RoutedEventArgs e)
        {
            Button btn = (Button)sender;
            info = false;
            Switcher.Switch(new Control.UCGestioUsuarisCon(((PersonaEntity)btn.DataContext).DNI,info));
        }

        /// <summary>
        /// Eliminar Usuari o Persona de la BBDD.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

       private void Eliminar_Click(object sender, RoutedEventArgs e)
        {
            
            Button btn =  (Button)sender;
            PersonaEntity persona = ((PersonaEntity)btn.DataContext);
            int id = persona.ID_Persona;
            MessageBox.Show("S'eliminarà l'Usuari o Persona: " + System.Environment.NewLine + persona.DNI + "" + persona.Nom + "" + persona.Cognom1, "Eliminar Usuari", MessageBoxButton.OK, MessageBoxImage.Information);

            try
            {

                ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
                servei.deletePersonaByID(id);
                servei.Close();
                
                Switcher.Switch(new UCGestioUsuaris());
                Alerta.alertaInfo(Textes.PersonaElimOk);
            }
            catch (Exception)
            {
                Alerta.alertaError1();
                Alerta.alertaInfo(Textes.PersonaElimNok);
            }

        }
        
        /// <summary>
        /// Informació de l'usuari seleccionat
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

       private void Info_Click(object sender, RoutedEventArgs e)
       {
           Button btn = (Button)sender;
           info = true;
           Switcher.Switch(new Control.UCGestioUsuarisCon(((PersonaEntity)btn.DataContext).DNI,info));
           
           
       }

        /// <summary>
        /// Canvi de l'estat Actiu d'una Persona
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Actiu_Click(object sender, RoutedEventArgs e)
        {
                        

        }

        private void cmbProperty_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            txtFilter.Focus();
        }


        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {

        }

        #endregion

        private void Image_ImageFailed(object sender, ExceptionRoutedEventArgs e)
        {

        }

    }
}
