﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ERPProduction.WPF.ServiceReference1;
using ERPProduction.WPF.Interface;
using ERPProduction.WPF.Util;

namespace ERPProduction.WPF.Control
{
    /// <summary>
    /// Lógica de interacción para UCGestioUsuarisCon.xaml
    /// </summary>
    public partial class UCGestioUsuarisCon : UserControl, ISwitchable
    {
        bool edit;
        /// <summary>
        /// Constructor per editar un Usuari o Persona registrat mitjançant el seu DNI
        /// </summary>
        /// <param name="DNI">DNI de la Persona a editar</param>
        public UCGestioUsuarisCon(string DNI, bool info)
        {
            
            InitializeComponent();
            comboPerfil();

            ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
            var persona = servei.buscarPersona(DNI);
            servei.Close();
            
            comboFromPersona(persona);
            wpnlUsuari.DataContext = persona;
            if (info)
            {
                txtbTitol.Text = "Informació d'Usuari";
                sPanelGrup.IsEnabled = false;
                btnDesarUser.Visibility = Visibility.Collapsed;
                btnRefrescarUser.Visibility = Visibility.Collapsed;
            }
            else
            {
                txtbTitol.Text = "Editar Usuari";
                txtDNI.IsReadOnly = true;
                btnRefrescarUser.Visibility = Visibility.Collapsed;
                edit = true;
            }
        }

        /// <summary>
        /// Constructor d'un nou Usuari o PErsona.
        /// </summary> 
        public UCGestioUsuarisCon()
        {
            InitializeComponent();
            comboPerfil();
            
            
            PersonaEntity persona = new PersonaEntity();
            persona.Actiu = true;
            persona.DataAlta = DateTime.Now;

            wpnlUsuari.DataContext = persona;
            txtbTitol.Text = "Afegir Usuari";
            btnRefrescarUser.Visibility = Visibility.Collapsed;
            edit = false;
        
        }

        #region ISwitchable Members

        void ISwitchable.UtilizeState(object state)
        {
            throw new NotImplementedException();
        }

        #endregion

        /// <summary>
        /// Carreguem el combox amb tots els Perfils
        /// </summary>
        private void comboPerfil()
        {
            ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
            cboxPerfil.DataContext = servei.GetAllPerfils();
            servei.Close();
        }

        private void comboFromPersona(PersonaEntity persona)
        {
            ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
            var perfil = servei.buscarPersona(persona.DNI);
            servei.Close();

            cboxPerfil.SelectedValue = ((PerfilEntity[])cboxPerfil.DataContext).Single(x => x.ID_Perfil == perfil.ID_Perfil);
        }


        /// <summary>
        /// 
        /// </summary>
        private void comboToFirstItem()
        {
            cboxPerfil.SelectedValue = ((PerfilEntity[])cboxPerfil.DataContext).First();

        }

        /// <summary>
        /// Validem els camps NO NUlls
        /// </summary>
        /// <returns></returns>
        private Boolean validacioCamps()
        {
            Boolean validacio = true;

            ///
            ///Validem camp no Null DNI
            ///

            if (String.IsNullOrEmpty(txtDNI.Text) == true)
            {
                Alerta.alertaInfo(Textes.campNoNull);
                txtDNI.Focus();
                return false;
            }

            ///
            ///Validem camp no Null Nom         
            ///

            if (String.IsNullOrEmpty(txtNom.Text) == true)
            {
                Alerta.alertaInfo(Textes.campNoNull);
                txtNom.Focus();
                return false;
            }

            return validacio;
        }

        #region Accions

        /// <summary>
        /// Desar o Actualitzar una Persona
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void Desar_Click(object sender, RoutedEventArgs e)
        {
            var persona = (PersonaEntity)wpnlUsuari.DataContext;

            if (validacioCamps())
            {

                persona.ID_Perfil = ((PerfilEntity)cboxPerfil.SelectedValue).ID_Perfil;

                ERPProductionClient servei = new ServiceReference1.ERPProductionClient();
                if (edit)
                {
                    try
                    {
                        servei.updatePersona(persona);
                        Alerta.alertaInfo(Textes.PersonaUpdateOk);
                    }
                    catch (Exception)
                    {
                        Alerta.alertaInfo(Textes.PersonaUpdateNok);
                    }
                }
                else
                {
                    try
                    {
                        servei.insertPersona(persona);
                        Alerta.alertaInfo(Textes.PersonaAddOk);
                    }
                    catch (Exception)
                    {
                        Alerta.alertaInfo(Textes.PersonaAddNok);
                    }
                }

                servei.Close();
                Switcher.Switch(new UCGestioUsuaris());
            }
            else
            {
                Alerta.alertaError(Textes.campsIncor);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Refrescar_Click(object sender, RoutedEventArgs e)
        {

        }

        /// <summary>
        /// Sortir de la pantalla de Edicio o creació de Persones, torna a pantalla principal Gestio d'Usuaris
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Sortir_Click(object sender, RoutedEventArgs e)
        {
            Switcher.Switch(new Control.UCGestioUsuaris());
        }

        #endregion


        private void image1_ImageFailed(object sender, ExceptionRoutedEventArgs e)
        {

        }

        private void Image_ImageFailed(object sender, ExceptionRoutedEventArgs e)
        {

        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            txtDNI.Focus();
        }

    }
}
