﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Data;
using System.Data.Linq;
using System.Runtime.Serialization;
using System.Text;
using ERPProduction.AccessDB;
using ERPProduction.Negoci;
using ERPProduction.NegociEntitats;
using System.ServiceModel;


namespace ERPProduction.WCF
{
    /// <summary>
    /// Interfícies amb API Lògica de Negoci
    /// </summary>

    [ServiceContract]
    public interface IERPProduction
    {

        #region Perfil
        /// <summary>
        /// Existeix Perfil
        /// </summary>
        /// <param name="ID_Perfil"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixPerfil(int ID_Perfil);

        /// <summary>
        /// Retorna tots el Perfils
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<PerfilEntity> GetAllPerfils();

        /// <summary>
        /// Retorna un Perfil segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns> 
        [OperationContract]
        List<PerfilEntity> llistarPerfil(int tipusConsulta, string valorBuscat);

        /// <summary>
        /// Inserta una Perfil
        /// </summary>
        /// <param name="perfil"></param>
        [OperationContract]
        void insertPerfil(PerfilEntity perfil);

        /// <summary>
        /// Esborra una Perfil
        /// </summary>
        /// <param name="Id"></param>
        [OperationContract]
        void deletePerfilById(int Id);

        /// <summary>
        /// Actualitza una Perfil
        /// </summary>
        /// <param name="perfil"></param>
        [OperationContract]
        void  updatePerfil(PerfilEntity perfil); 
        #endregion

        #region Persona
        /// <summary>
        ///  Existeix Persona
        /// </summary>
        /// <param name="ID_Persona"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixPersona(int ID_Persona);

        /// <summary>
        /// Buscar Persona per DNI
        /// </summary>
        /// <param name="DNI"></param>
        /// <returns></returns>
        [OperationContract]
        PersonaEntity buscarPersona(string DNI);

        /// <summary>
        /// Buscar Persona per ID_Persona
        /// </summary>
        /// <param name="ID_Persona"></param>
        /// <returns></returns>
        [OperationContract]
        PersonaEntity buscarPersonaId(int ID_Persona);
        
        /// <summary>
        /// Retorna totes les Persones.
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<PersonaEntity> GetAllPersones();

        /// <summary>
        /// Retorna un Perfil segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns>
        [OperationContract]
        List<PersonaEntity> llistarPersona(int tipusConsulta, string valorBuscat);
        
        /// <summary>
        /// Inserta una Persona
        /// </summary>
        /// <param name="persona"></param>
        [OperationContract]
        void insertPersona(PersonaEntity persona);

        /// <summary>
        ///  Esborra una Persona
        /// </summary>
        /// <param name="ID_Persona"></param>
        [OperationContract]
        void deletePersonaByID(int ID_Persona);

        /// <summary>
        /// Actualitza una Persona
        /// </summary>
        /// <param name="persona"></param>
        [OperationContract]
        void updatePersona(PersonaEntity persona);

        /// <summary>
        /// Actualitza estat Actiu d'una Persona
        /// </summary>
        /// <param name="DNI"></param>
        /// <param name="actiu"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean updateActiu(string DNI, bool actiu);

        /// <summary>
        /// Valida Login de la PErsona
        /// </summary>
        /// <param name="DNI"></param>
        /// <param name="contrasenya"></param>
        /// <returns></returns>
        [OperationContract]
        int validarLoginPersona(string DNI, string contrasenya);

       /// <summary>
        /// Canviar contrasenya Persona WEB
       /// </summary>
       /// <param name="ID_Persona"></param>
       /// <param name="telefon"></param>
       /// <param name="email"></param>
        [OperationContract]
        void canviContrasenyaPersonaWeb(int id_Persona, string contrasenya);
        #endregion

        #region Usuari
        /// <summary>
        /// Existeix Usuari
        /// </summary>
        /// <param name="Login"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixUsuari(int ID_Usuari);

        /// <summary>
        /// Retorna tots els Usuaris registrats
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<UsuarisEntity> GetAllUsuaris();

        /// <summary>
        /// Retorna un Usuari segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns>
        [OperationContract]
        List<UsuarisEntity> llistarUsuari(int tipusConsulta, string valorBuscat);

        /// <summary>
        /// Buscar un Usuari
        /// </summary>
        /// <param name="Login"></param>
        /// <returns></returns>
        [OperationContract]
        UsuarisEntity buscarUsuari(int ID_Usuari);

        /// <summary>
        /// Inserta un Usuari
        /// </summary>
        /// <param name="usuari"></param>
        [OperationContract]
        void insertUsuari(UsuarisEntity usuari);

        /// <summary>
        /// Esborra un Usuari
        /// </summary>
        /// <param name="Login"></param>
        [OperationContract]
        void deleteUsuariById(int ID_usuari);

        /// <summary>
        /// Actualitza un Usuari
        /// </summary>
        /// <param name="usuari"></param>
        [OperationContract]
        void  updateUsuari(UsuarisEntity usuari);

        
        #endregion
        
        #region Divisio
        /// <summary>
        /// Existeix Divisio
        /// </summary>
        /// <param name="ID_Divisio"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixDivisio(int ID_Divisio);

        /// <summary>
        /// Retorna totes les Divisions
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<DivisioEntity> GetAllDivisions();

        /// <summary>
        /// Buscar una Divisio
        /// </summary>
        /// <param name="ID_Divisio"></param>
        /// <returns></returns>
        [OperationContract]
        DivisioEntity buscarDivisio(int ID_Divisio);

        /// <summary>
        /// Inserta una Divisio
        /// </summary>
        /// <param name="divisio"></param>
        [OperationContract]
        void insertDivisio(DivisioEntity divisio);

        /// <summary>
        /// Esborra una Divisio
        /// </summary>
        /// <param name="ID_Divisio"></param>
        [OperationContract]
        void deleteDivisioById(int ID_Divisio);

        /// <summary>
        /// Actualitza una Divisio
        /// </summary>
        /// <param name="divisio"></param>
        [OperationContract]
        void  updateDivisio(DivisioEntity divisio);
        #endregion

        #region Producte
        /// <summary>
        /// Existeix Producte
        /// </summary>
        /// <param name="ID_Producte"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixProducte(int ID_Producte);

        /// <summary>
        ///  Retorna totes els Productes
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<ProducteEntity> GetAllProductes();

        /// <summary>
        /// Retorna un Producte segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns>
        [OperationContract]
        List<ProducteEntity> llistarProducte(int tipusConsulta, string valorBuscat);

        /// <summary>
        /// Buscar un Producte
        /// </summary>
        /// <param name="ID_Producte"></param>
        /// <returns></returns>
        [OperationContract]
        ProducteEntity buscarProducte(int ID_Producte);

        /// <summary>
        /// Inserta un Producte
        /// </summary>
        /// <param name="producte"></param>
        [OperationContract]
        void insertProducte(ProducteEntity producte);

        /// <summary>
        /// Esborra un Producte
        /// </summary>
        /// <param name="ID_Producte"></param>
        [OperationContract]
        void deleteProducteById(int ID_Producte);

        /// <summary>
        ///  Actualitza un Producte
        /// </summary>
        /// <param name="producte"></param>
        [OperationContract]
        void updateProducte(ProducteEntity producte);
        #endregion

        #region Familia
        /// <summary>
        /// Existeix Familia
        /// </summary>
        /// <param name="ID_Familia"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixFamilia(int ID_Familia);

        /// <summary>
        /// Retorna totes les Families
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<FamiliaEntity> GetAllFamilies();

        /// <summary>
        /// Buscar una Familia
        /// </summary>
        /// <param name="ID_Familia"></param>
        /// <returns></returns>
        [OperationContract]
        FamiliaEntity buscarFamilia(int ID_Familia);

        /// <summary>
        ///  Inserta una Familia
        /// </summary>
        /// <param name="familia"></param>
        [OperationContract]
        void insertFamilia(FamiliaEntity familia);

        /// <summary>
        ///  Esborra una Familia
        /// </summary>
        /// <param name="ID_Familia"></param>
        [OperationContract]
        void deleteFamiliaById(int ID_Familia);

        /// <summary>
        /// Actualitza una Familia
        /// </summary>
        /// <param name="familia"></param>
        [OperationContract]
        void updateFamilia(FamiliaEntity familia);
        #endregion

        #region Estructura
        /// <summary>
        /// Existeix Estructura
        /// </summary>
        /// <param name="ID_Estructura"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixEstructura(int ID_Estructura);

        /// <summary>
        /// Retorna totes les Estructures
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<EstructuraEntity> GetAllEstructures();

        /// <summary>
        /// Retorna una Estructura segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns> 
        [OperationContract]
        List<EstructuraEntity> llistarEstructura(int tipusConsulta, string valorBuscat);

        /// <summary>
        /// Podem buscar una Estructura per algun del seus camps TO DO...
        /// </summary>
        /// <param name="ID_Estructura"></param>
        /// <returns></returns>
        [OperationContract]
        EstructuraEntity buscarEstructura(int ID_Estructura);

        /// <summary>
        /// Inserta una Estructura
        /// </summary>
        /// <param name="estructura"></param>
        [OperationContract]
        void insertEstructura(EstructuraEntity estructura);

        /// <summary>
        /// Esborra una Estructura
        /// </summary>
        /// <param name="ID_Estructura"></param>
        [OperationContract]
        void deleteEstructuraById(int ID_Estructura);

        /// <summary>
        /// Actualitza una Estructura
        /// </summary>
        /// <param name="estructura"></param>
        [OperationContract]
        void updateEstructura(EstructuraEntity estructura);
        #endregion

        #region Component
        /// <summary>
        /// Existeix Component
        /// </summary>
        /// <param name="ID_Component"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixComponent(int ID_Component);

        /// <summary>
        /// Retorna tots els Components
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<ComponentEntity> GetAllComponents();

        /// <summary>
        /// Retorna un Component segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns>
        [OperationContract]
        List<ComponentEntity> llistarComponent(int tipusConsulta, string valorBuscat);

        /// <summary>
        ///  Podem buscar un component per algun del seus camps TO DO...
        /// </summary>
        /// <param name="ID_Component"></param>
        /// <returns></returns>
        [OperationContract]
        ComponentEntity buscarComponent(int ID_Component);

        /// <summary>
        /// Inserta un Component
        /// </summary>
        /// <param name="component"></param>
        [OperationContract]
        void insertComponent(ComponentEntity component);

        /// <summary>
        /// Esborra un Component
        /// </summary>
        /// <param name="ID_Component"></param>
        [OperationContract]
        void deleteComponentById(int ID_Component);

        /// <summary>
        /// Actualitza un Component
        /// </summary>
        /// <param name="component"></param>
        [OperationContract]
        void updateComponent(ComponentEntity component);
        #endregion

        #region Foto

        #endregion

        #region Empresa
        /// <summary>
        ///  Existeix Empresa
        /// </summary>
        /// <param name="ID_Empresa"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixEmpresa(int ID_Empresa);

        /// <summary>
        /// Buscar Empresa per Nom  
        /// </summary>
        /// <param name="Nom_Empresa"></param>
        /// <returns></returns>
        [OperationContract]
        EmpresaEntity buscarEmpresa(int ID_Empresa);

        /// <summary>
        ///  Inserta una Empresa
        /// </summary>
        /// <param name="empresa"></param>
        [OperationContract]
        void insertEmpresa(EmpresaEntity empresa);

        /// <summary>
        /// Actualitza una Empresa
        /// </summary>
        /// <param name="operacio"></param>
        [OperationContract]
        void updateEmpresa(EmpresaEntity empresa);

        /// <summary>
        ///  Esborra una Empresa
        /// </summary>
        /// <param name="ID_Empresa"></param>
        [OperationContract]
        void deleteEmpresaByID(int ID_Empresa);

        #endregion

        #region Operacio
        /// <summary>
        /// Existeix Operacio
        /// </summary>
        /// <param name="ID_Operacio"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixOperacio(int ID_Operacio);

        /// <summary>
        /// Retorna totes les Operacions
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<OperacioEntity> GetAllOperacions();

        /// <summary>
        ///  Retorna una Operacio segons parametres
        /// </summary>
        /// <param name="tipusConsulta"></param>
        /// <param name="valorBuscat"></param>
        /// <returns></returns>
        [OperationContract]
        List<OperacioEntity> llistarOperacio(int tipusConsulta, string valorBuscat);

        /// <summary>
        /// Podem buscar una Operacio per algun del seus camps
        /// </summary>
        /// <param name="ID_Operacio"></param>
        /// <returns></returns>
        [OperationContract]
        OperacioEntity buscarOperacio(int ID_Operacio);

        /// <summary>
        /// Inserta una Operacio
        /// </summary>
        /// <param name="operacio"></param>
        [OperationContract]
        void insertOperacio(OperacioEntity operacio);

        /// <summary>
        /// Esborra una Operacio
        /// </summary>
        /// <param name="ID_Operacio"></param>
        [OperationContract]
        void deleteOperacioById(int ID_Operacio);

        /// <summary>
        /// Actualitza una Operacio
        /// </summary>
        /// <param name="operacio"></param>
        [OperationContract]
        void updateOperacio(OperacioEntity operacio);

        #endregion

        #region TipusComponent
        /// <summary>
        /// Existeix Tipus Component
        /// </summary>
        /// <param name="ID_Tipus_Compo"></param>
        /// <returns></returns>
        [OperationContract]
        Boolean existeixTipusCompo(int ID_Tipus_Compo);

        /// <summary>
        /// Retorna tots els Tipus de Components
        /// </summary>
        /// <returns></returns>
        [OperationContract]
        List<TipusComponentsEntity> GetAllTipusCompo();

        /// <summary>
        ///  Inserta un Tipus de Component
        /// </summary>
        /// <param name="tipusCompo"></param>
        [OperationContract]
        void insertTipusCompo(TipusComponentsEntity tipusCompo);

        /// <summary>
        /// Esborra un Tipus de Component
        /// </summary>
        /// <param name="ID_Tipus_Compo"></param>
 
        [OperationContract]
        void deleteTipusCompoById(int ID_Tipus_Compo);

       /// <summary>
       /// Actualitza un Tipus de Component
       /// </summary>
       /// <param name="tipusCompo"></param>
        [OperationContract]
        void updateTipusCompo(TipusComponentsEntity tipusCompo);

        #endregion


    }
}
